'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var ethers = require('ethers');

function isAddress(address) {
    return /^(0x)?[0-9a-fA-F]{40}$/g.test(address);
}
function toChecksumAddress(address) {
    if (!ethers.ethers.utils.isHexString(address, 20)) {
        throw new Error(`Invalid address ${address}`);
    }
    address = address.toLowerCase();
    const chars = address.substring(2).split('');
    const expanded = new Uint8Array(40);
    for (let i = 0; i < 40; i++) {
        expanded[i] = chars[i].charCodeAt(0);
    }
    const hashed = ethers.ethers.utils.arrayify(ethers.ethers.utils.keccak256(expanded));
    for (let i = 0; i < 40; i += 2) {
        if ((hashed[i >> 1] >> 4) >= 8) {
            chars[i] = chars[i].toUpperCase();
        }
        if ((hashed[i >> 1] & 0x0f) >= 8) {
            chars[i + 1] = chars[i + 1].toUpperCase();
        }
    }
    return '0x' + chars.join('');
}

const formatCPC = ethers.utils.formatEther;
const parseCPC = ethers.utils.parseEther;

Object.defineProperty(exports, 'default', {
    enumerable: true,
    get: function () { return ethers.utils; }
});
exports.formatCPC = formatCPC;
exports.isAddress = isAddress;
exports.parseCPC = parseCPC;
exports.toChecksumAddress = toChecksumAddress;
